@@ -19,7 +19,7 @@ class SelectFields(DeepCopyPipe):
         return usage
 
     def __init__(self, ptok: ParsedToken, usage: Usage):
-        super().__init__(ptok)
+        super().__init__(ptok, usage)
 
         arg_string = usage.get_arg('fields')
         if not arg_string:
